/*
 * Copyright (C) 2012 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

#ifndef _SIMBODY_MESHSHAPE_HH_
#define _SIMBODY_MESHSHAPE_HH_

#include "gazebo/physics/MeshShape.hh"
#include "gazebo/util/system.hh"

namespace gazebo
{
  namespace physics
  {
    class SimbodyMesh;

    /// \ingroup gazebo_physics
    /// \addtogroup gazebo_physics_simbody Simbody Physics
    /// \{

    /// \brief Triangle mesh collision
    class GZ_PHYSICS_VISIBLE SimbodyMeshShape : public MeshShape
    {
      /// \brief Constructor
      public: explicit SimbodyMeshShape(CollisionPtr _parent);

      /// \brief Destructor
      public: virtual ~SimbodyMeshShape();

      // Documentation inherited
      public: virtual void Load(sdf::ElementPtr _sdf);

      // Documentation inherited
      protected: virtual void Init();

      /// \brief Simbody collision mesh helper class
      private: SimbodyMesh *simbodyMesh;
    };
    /// \}
  }
}
#endif

